@@ -36,15 +36,10 @@
 #include "nothing.h"
 #include "panel.h"
 #include "panel-a11y.h"
-#include "egg-screen-exec.h"
-#include "egg-screen-url.h"
-#include "egg-screen-help.h"
 #include "xstuff.h"
 #include "panel-globals.h"
 #include "launcher.h"
 
-static gboolean panel_is_url (const char *url);
-
 int
 panel_ditem_launch (const GnomeDesktopItem       *item,
 		    GList                        *file_list,
@@ -67,7 +62,7 @@ panel_show_help (GdkScreen  *screen,
 {
 	GError *error = NULL;
 
-	if (!egg_help_display_desktop_on_screen (NULL, "user-guide", doc_name, linkid, screen, &error)) {
+	if (!gnome_help_display_desktop_on_screen (NULL, "user-guide", doc_name, linkid, screen, &error)) {
 		panel_error_dialog (
 			screen,
 			"cannot_show_help",
@@ -79,228 +74,6 @@ panel_show_help (GdkScreen  *screen,
 	}
 }
 
-static gboolean
-panel_show_gnome_help (GdkScreen   *screen,
-		       const char  *docpath,
-		       GError     **error)
-{
-	char *app, *p, *path;
-	gboolean retval;
-
-	app = g_strdup (docpath);
-
-	p = strchr (app, '/');
-
-	if (p == NULL) {
-		g_free (app);
-		g_set_error (error,
-			     PANEL_HELP_ERROR,
-			     PANEL_HELP_ERROR_NOT_FOUND,
-			     /* XXX: Not really a correct error,
-			      * but just somewhat correct */
-			     _("Help document not found"));
-		return FALSE;
-	}
-
-	path = p+1;
-	*p = '\0';
-
-	retval = TRUE;
-
-	if ( ! egg_help_display_desktop_on_screen (NULL, app, path, NULL, screen, error)) {
-		/* We wish to get the error from the first call, and not the second
-		   (since what would we do on both being set, which at best results
-		   in GError warnings) */
-		/* FIXME: perhaps merge error texts and create a new error */
-		retval = egg_help_display_with_doc_id_on_screen (
-				NULL, app, path, NULL, screen, NULL);
-		if (retval)
-			g_clear_error (error);
-	}
-
-	g_free (app);
-
-	return retval;
-}
-
-static gboolean
-panel_show_kde_help (GdkScreen   *screen,
-		     const char  *docpath,
-		     GError     **error)
-{
-	const GList *li;
-
-	if ( ! g_file_test (KDE_DOCDIR, G_FILE_TEST_EXISTS)) {
-		g_set_error (error,
-			     PANEL_HELP_ERROR,
-			     PANEL_HELP_ERROR_NOT_FOUND,
-			     _("Help document not found"));
-		return FALSE;
-	}
-
-	for (li = gnome_i18n_get_language_list ("LC_MESSAGES");
-	     li != NULL;
-	     li = li->next) {
-		char *fullpath = g_strdup_printf ("%s/HTML/%s/%s",
-						  KDE_DOCDIR,
-						  (char *)li->data,
-						  docpath);
-		if (g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
-			gboolean retval;
-			char *uri = g_strconcat ("ghelp:", fullpath, NULL);
-			g_free (fullpath);
-			retval = egg_help_display_uri_on_screen (uri, screen, error);
-			g_free (uri);
-			return retval;
-		}
-		g_free (fullpath);
-	}
-
-	g_set_error (error,
-		     PANEL_HELP_ERROR,
-		     PANEL_HELP_ERROR_NOT_FOUND,
-		     _("Help document not found"));
-
-	return FALSE;
-}
-
-gboolean
-panel_show_gnome_kde_help (GdkScreen   *screen,
-			   const char  *docpath,
-			   GError     **error)
-{
-	if (string_empty (docpath)) {
-		g_set_error (error,
-			     PANEL_HELP_ERROR,
-			     PANEL_HELP_ERROR_NO_DOCPATH,
-			     _("No document to show"));
-		return FALSE;
-	}
-
-	if (panel_is_url (docpath))
-		return egg_help_display_uri_on_screen (docpath, screen, error);
-
-	if ( ! panel_show_gnome_help (screen, docpath, error)) {
-		/* we don't want to pass error to panel_show_kde_help.
-		   If we fail we wish to display the error we got from
-		   panel_show_gnome_help.  Not to mention that if
-		   we pass the error here we get GError errors about
-		   resetting an error (and a memleak) */
-		/* FIXME: perhaps merge error texts and create a new error */
-		gboolean ret = panel_show_kde_help (screen, docpath, NULL);
-		if (ret)
-			g_clear_error (error);
-		return ret;
-	}
-
-	return TRUE;
-}
-
-GQuark
-panel_help_error_quark (void)
-{
-	static GQuark q = 0;
-	if (q == 0)
-		q = g_quark_from_static_string ("panel-help-error-quark");
-
-	return q;
-}
-
-static void
-updated (GtkWidget *w, gpointer data)
-{
-	UpdateFunction func = g_object_get_data (G_OBJECT (w), "update_function");
-
-	func (data);
-}
-
-GtkWidget *
-create_text_entry(GtkWidget *table,
-		  const char *history_id,
-		  int row,
-		  const char *label,
-		  const char *text,
-		  UpdateFunction func,
-		  gpointer data)
-{
-	GtkWidget *wlabel;
-	GtkWidget *entry;
-	GtkWidget *t;
-
-	wlabel = gtk_label_new(label);
-	gtk_misc_set_alignment(GTK_MISC(wlabel), 0.0, 0.5);
-	gtk_table_attach(GTK_TABLE(table), wlabel,
-			 0, 1, row, row + 1,
-			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			 GTK_FILL | GTK_SHRINK,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	gtk_widget_show(wlabel);
-
-	entry = gnome_entry_new(history_id);
-	t = gnome_entry_gtk_entry (GNOME_ENTRY (entry));
-	if (text)
-		gtk_entry_set_text(GTK_ENTRY(t), text);
-	gtk_table_attach(GTK_TABLE(table), entry,
-			 1, 2, row, row + 1,
-			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			 GTK_FILL | GTK_SHRINK,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	panel_a11y_set_atk_relation (entry, GTK_LABEL (wlabel));
-
-	if(func) {
-		g_object_set_data (G_OBJECT (t), "update_function", func);
-		g_signal_connect (G_OBJECT (t), "changed",
-				  G_CALLBACK (updated), 
-				  data);
-	}
-	return entry;
-}
-
-GtkWidget *
-create_icon_entry(GtkWidget *table,
-		  const char *history_id,
-		  int cols, int cole,
-		  const char *label,
-		  const char *subdir,
-		  const char *text,
-		  UpdateFunction func,
-		  gpointer data)
-{
-	GtkWidget *wlabel;
-	GtkWidget *entry;
-
-	wlabel = gtk_label_new(label);
-	gtk_misc_set_alignment(GTK_MISC(wlabel), 0.0, 0.5);
-	gtk_table_attach(GTK_TABLE(table), wlabel,
-			 cols, cole, 2, 3,
-			 GTK_SHRINK,
-			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	gtk_widget_show(wlabel);
-
-	entry = gnome_icon_entry_new (history_id, _("Browse"));
-
-	gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY(entry), subdir);
-	if (text != NULL)
-		gnome_icon_entry_set_filename (GNOME_ICON_ENTRY(entry), text);
-
-	panel_a11y_set_atk_relation (entry, GTK_LABEL (wlabel));
-	gtk_table_attach(GTK_TABLE(table), entry,
-			 cols, cole, 1, 2,
-			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			 GTK_FILL | GTK_SHRINK,
-			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-
-	if(func) {
-		g_object_set_data (G_OBJECT (entry), "update_function", func);
-		g_signal_connect (G_OBJECT (entry), "changed",
-				  G_CALLBACK (updated), 
-				  data);
-	}
-
-	return entry;
-}
-
 GList *
 panel_g_list_insert_before (GList *list,
 			    GList *sibling,
@@ -523,24 +296,6 @@ panel_find_applet_index (GtkWidget *widget)
 	return i;
 }
 
-/* is url showable by gnome_url_show */
-static gboolean
-panel_is_url (const char *url)
-{
-	if (strncmp (url, "http://", strlen ("http://")) == 0 ||
-	    strncmp (url, "https://", strlen ("https://")) == 0 ||
-	    strncmp (url, "gopher://", strlen ("gopher://")) == 0 ||
-	    strncmp (url, "ftp://", strlen ("ftp://")) == 0 ||
-	    strncmp (url, "file:", strlen ("file:")) == 0 ||
-	    strncmp (url, "ghelp:", strlen ("ghelp:")) == 0 ||
-	    strncmp (url, "help:", strlen ("help:")) == 0 ||
-	    strncmp (url, "man:", strlen ("man:")) == 0 ||
-	    strncmp (url, "info:", strlen ("info:")) == 0)
-		return TRUE;
-	else
-		return FALSE;
-}
-
 void
 panel_push_window_busy (GtkWidget *window)
 {
@@ -950,18 +705,23 @@ missing_pixbuf (int size)
 void
 panel_lock_screen (GdkScreen *screen)
 {
-	char *argv[3] = {"xscreensaver-command", "-lock", NULL};
+#define XSCREENSAVER_LOCK_COMMAND "xscreensaver-command -lock"
 
-	if (!screen)
-		screen = gdk_screen_get_default ();
+	GError *error = NULL;
 
-	if (egg_screen_execute_async (screen, g_get_home_dir (), 2, argv) < 0)
+	g_return_if_fail (GDK_IS_SCREEN (screen));
+
+	if (!gdk_spawn_command_line_on_screen (screen, XSCREENSAVER_LOCK_COMMAND, &error)) {
 		panel_error_dialog (screen,
-			"cannot_exec_xscreensaver",
-			 _("Cannot execute %s"),
-			 _("%s - command not found"),
-			 "xscreensaver",
-			 "xscreensaver");
+				    "cannot_exec_xscreensaver",
+				    _("Cannot execute '%s'"),
+				    "%s",
+				    XSCREENSAVER_LOCK_COMMAND,
+				    error->message);
+		g_error_free (error);
+	}
+	
+#undef XSCREENSAVER_LOCK_COMMAND
 }
 
 
